@@ -2,7 +2,7 @@
  *  Hamlib CI-V backend - low level communication routines
  *  Copyright (c) 2000-2006 by Stephane Fillod
  *
- *	$Id: frame.c,v 1.28 2006/02/26 18:48:07 fillods Exp $
+ *	$Id: frame.c,v 1.31 2006/10/07 20:45:40 csete Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -47,11 +47,11 @@
  * REM: if "data" is NULL, then "data_len" MUST be 0.
  *
  * NB: the frame array must be big enough to hold the frame.
- * 		The smallest frame is 8 bytes, the biggest is at least 13 bytes.
+ * 		The smallest frame is 6 bytes, the biggest is at least 13 bytes.
  *
  * TODO: inline the function?
  */
-int make_cmd_frame(char frame[], char re_id, char cmd, int subcmd, const char *data, int data_len)
+int make_cmd_frame(char frame[], char re_id, char cmd, int subcmd, const unsigned char *data, int data_len)
 {	
 	int i = 0;
 
@@ -63,9 +63,17 @@ int make_cmd_frame(char frame[], char re_id, char cmd, int subcmd, const char *d
 	frame[i++] = re_id;
 	frame[i++] = CTRLID;
 	frame[i++] = cmd;
-	if (subcmd != -1)
-			frame[i++] = subcmd & 0xff;
-
+	if (subcmd != -1) {
+#ifdef MULTIB_SUBCMD
+		register int j;
+		if ((j = subcmd & 0xff0000)) {  /* allows multi-byte subcmd for dsp rigs */
+			frame[i++] = j >> 16;
+			frame[i++] = (subcmd & 0xff00) >> 8;
+		}
+		else if ((j = subcmd & 0xff00)) frame[i++] = j >> 8;
+#endif
+		frame[i++] = subcmd & 0xff;
+	}	
 	if (data_len != 0) {
 		memcpy(frame+i, data, data_len);
 		i += data_len;
@@ -88,7 +96,7 @@ int make_cmd_frame(char frame[], char re_id, char cmd, int subcmd, const char *d
  * return RIG_OK if transaction completed, 
  * or a negative value otherwise indicating the error.
  */
-int icom_one_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int payload_len, char *data, int *data_len)
+int icom_one_transaction (RIG *rig, int cmd, int subcmd, const unsigned char *payload, int payload_len, unsigned char *data, int *data_len)
 {
 	struct icom_priv_data *priv;
 	struct rig_state *rs;
@@ -99,8 +107,8 @@ int icom_one_transaction (RIG *rig, int cmd, int subcmd, const char *payload, in
 	rs = &rig->state;
 	priv = (struct icom_priv_data*)rs->priv;
 
-	frm_len = make_cmd_frame(sendbuf, priv->re_civ_addr, cmd, subcmd, 
-					payload, payload_len);
+	frm_len = make_cmd_frame((char *) sendbuf, priv->re_civ_addr, cmd, subcmd, 
+                                 payload, payload_len);
 
 	/* 
 	 * should check return code and that write wrote cmd_len chars! 
@@ -109,7 +117,7 @@ int icom_one_transaction (RIG *rig, int cmd, int subcmd, const char *payload, in
 
 	serial_flush(&rs->rigport);
 
-	retval = write_block(&rs->rigport, sendbuf, frm_len);
+	retval = write_block(&rs->rigport, (char *) sendbuf, frm_len);
 	if (retval != RIG_OK) {
 			Unhold_Decode(rig);
 			return retval;
@@ -235,7 +243,7 @@ int icom_one_transaction (RIG *rig, int cmd, int subcmd, const char *payload, in
  * return RIG_OK if transaction completed, 
  * or a negative value otherwise indicating the error.
  */
-int icom_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int payload_len, char *data, int *data_len)
+int icom_transaction (RIG *rig, int cmd, int subcmd, const unsigned char *payload, int payload_len, unsigned char *data, int *data_len)
 {
 	int retval, retry;
 
@@ -264,7 +272,7 @@ int read_icom_frame(hamlib_port_t *p, unsigned char rxbuffer[])
 {
 	int i;
 
-	i = read_string(p, rxbuffer, MAXFRAMELEN, 
+	i = read_string(p, (char *) rxbuffer, MAXFRAMELEN, 
 			icom_block_end, icom_block_end_length);
 
 	return i;
@@ -283,7 +291,7 @@ int read_icom_frame(hamlib_port_t *p, unsigned char rxbuffer[])
  * assumes rig!=NULL
  */
 int rig2icom_mode(RIG *rig, rmode_t mode, pbwidth_t width, 
-				unsigned char *md, char *pd)
+				unsigned char *md, signed char *pd)
 {
 	unsigned char icmode;
 	signed char icmode_ext;
@@ -309,7 +317,7 @@ int rig2icom_mode(RIG *rig, rmode_t mode, pbwidth_t width,
 
 	medium_width = rig_passband_normal(rig, mode);
 	if (width == medium_width || width == RIG_PASSBAND_NORMAL)
-			icmode_ext = -1;	/* medium, no passband data */
+			icmode_ext = -1;	/* medium, no passband data-> rig default. Is medium always the default? */
 	else if (width < medium_width)
 			icmode_ext = PD_NARROW;
 	else
@@ -354,6 +362,8 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode, pbwidth_t
 	case S_LSB:	*mode = RIG_MODE_LSB; break;
 	case S_RTTY:	*mode = RIG_MODE_RTTY; break;
 	case S_RTTYR:	*mode = RIG_MODE_RTTYR; break;
+	case S_PSK:	*mode = RIG_MODE_PKTUSB; break;	/* IC-7800 */
+	case S_PSKR:	*mode = RIG_MODE_PKTLSB; break;
 	case 0xff:	*mode = RIG_MODE_NONE; break;	/* blank mem channel */
 
 	default:
@@ -362,26 +372,40 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode, pbwidth_t
 		*mode = RIG_MODE_NONE;
 	}
 	
-	/* IC-R75 returns passband indexes 1-wide, 2-normal,3-narrow */
-	if ((rig->caps->rig_model == RIG_MODEL_ICR75) || 
-			(rig->caps->rig_model == RIG_MODEL_IC756PROII))
-		pd = 3-pd;
+	/* Most rigs return 1-wide, 2-narrow; or if it has 3 filters: 1-wide, 2-middle,
+           3-narrow. (Except for the 706 mkIIg 0-wide, 1-middle, 2-narrow.)  For DSP
+           rigs these are presets, which can be programmed for 30 - 41 bandwidths,
+           depending on mode  */
+
+	if (rig->caps->rig_model == RIG_MODEL_IC706MKIIG ||
+            rig->caps->rig_model == RIG_MODEL_IC706 ||
+            rig->caps->rig_model ==  RIG_MODEL_IC706MKII) pd--;
 	
 	switch (pd) {
-		case 0x00: *width = rig_passband_narrow(rig, *mode); break;
-		case 0x01: *width = rig_passband_normal(rig, *mode); break;
-		case 0x02: *width = rig_passband_wide(rig, *mode); break;
-		case -1: break;		/* no passband data */
-	case 0x03:
-		if (rig->caps->rig_model == RIG_MODEL_IC751) {
-			*width = rig_passband_narrow(rig, *mode);
-			break;
-		}
-		/* else fall through */
-	default:
-		rig_debug(RIG_DEBUG_ERR,"icom: Unsupported Icom mode width %#.2x\n",
-						pd);
-		*width = RIG_PASSBAND_NORMAL;
+		case 0x01: 
+                  /* if no wide filter defined it's the default */
+                  if (!(*width = rig_passband_wide(rig, *mode)))  
+                    *width = rig_passband_normal(rig, *mode);
+                  break;
+
+		case 0x02:
+                  if ((*width = rig_passband_wide(rig, *mode)))
+                    *width = rig_passband_normal(rig, *mode); 
+                  else
+                    /* This really just depends on how you program the table. */
+                    *width = rig_passband_narrow(rig, *mode);
+                  break;
+
+		case 0x03:
+                  *width = rig_passband_narrow(rig, *mode);
+                  break;
+
+		case -1:
+                  break;		/* no passband data */
+	
+	        default:
+                  rig_debug(RIG_DEBUG_ERR,"icom: Unsupported Icom mode width %#.2x\n", pd);
 	}
+return ;
 }
 
