@@ -1,8 +1,8 @@
 /*
  *  Hamlib CI-V backend - main header
- *  Copyright (c) 2000-2003 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: icom.h,v 1.64 2004/02/02 22:15:17 fillods Exp $
+ *	$Id: icom.h,v 1.74 2006/11/07 12:21:39 n0nb Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -27,14 +27,22 @@
 #include <cal.h>
 #include <tones.h>
 
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+
+#define BACKEND_VER "0.4"
+
 /*
  * defines used by comp_cal_str in rig.c
- * STR_CAL_LENGTH is the lenght of the S Meter calibration table
+ * STR_CAL_LENGTH is the length of the S Meter calibration table
  * STR_CAL_S0 is the value in dB of the lowest value (not even in table)
+ * MULTIB_SUBCMD allows the dsp rigs ie pro models to use multibyte subcommands for all the extra
+ * parameters and levels.
  */
 #define STR_CAL_LENGTH 16
 #define STR_CAL_S0 -54
-
+#define MULTIB_SUBCMD
 
 /*
  * minimal channel caps.
@@ -62,6 +70,12 @@
 	.rptr_offs = 1,	\
 } 
 
+/*
+ * S-Meter data for uncalibrated rigs
+ */
+#define UNKNOWN_IC_STR_CAL { 2, {{ 0, -60}, { 255, 60}} }
+
+
 struct ts_sc_list {
 	shortfreq_t ts;	/* tuning step */
 	unsigned char sc;	/* sub command */
@@ -104,9 +118,14 @@ extern const struct ts_sc_list r9000_ts_sc_list[];
 extern const struct ts_sc_list ic756_ts_sc_list[];
 extern const struct ts_sc_list ic756pro_ts_sc_list[];
 extern const struct ts_sc_list ic706_ts_sc_list[];
+extern const struct ts_sc_list ic7000_ts_sc_list[];
 extern const struct ts_sc_list ic910_ts_sc_list[];
 extern const struct ts_sc_list ic718_ts_sc_list[];
 
+extern const pbwidth_t rtty_fil[];	/* rtty filter passband width; available on pro rigs */
+
+pbwidth_t icom_get_dsp_flt(RIG *rig, rmode_t mode);
+
 int icom_init(RIG *rig);
 int icom_cleanup(RIG *rig);
 int icom_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
@@ -143,6 +162,8 @@ int icom_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 int icom_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 int icom_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
 int icom_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status);
+int icom_set_parm(RIG *rig, setting_t parm, value_t val);
+int icom_get_parm(RIG *rig, setting_t parm, value_t *val);
 int icom_set_conf(RIG *rig, token_t token, const char *val);
 int icom_get_conf(RIG *rig, token_t token, char *val);
 int icom_set_powerstat(RIG *rig, powerstat_t status);
@@ -170,13 +191,20 @@ extern const struct rig_caps ic746pro_caps;
 extern const struct rig_caps ic756_caps;
 extern const struct rig_caps ic756pro_caps;
 extern const struct rig_caps ic756pro2_caps;
+extern const struct rig_caps ic756pro3_caps;
+extern const struct rig_caps ic751_caps;
+extern const struct rig_caps ic761_caps;
 extern const struct rig_caps ic765_caps;
 extern const struct rig_caps ic775_caps;
+extern const struct rig_caps ic78_caps;
+extern const struct rig_caps ic7800_caps;
+extern const struct rig_caps ic7000_caps;
 extern const struct rig_caps ic781_caps;
 extern const struct rig_caps ic821h_caps;
 extern const struct rig_caps ic910_caps;
 extern const struct rig_caps ic970_caps;
 extern const struct rig_caps icr10_caps;
+extern const struct rig_caps icr20_caps;
 extern const struct rig_caps icr71_caps;
 extern const struct rig_caps icr72_caps;
 extern const struct rig_caps icr75_caps;
