@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TH-G71 description
- *  Copyright (c) 2003-2004 by Stephane Fillod
+ *  Copyright (c) 2003-2005 by Stephane Fillod
  *
- *	$Id: thg71.c,v 1.13 2004/06/13 12:35:30 fillods Exp $
+ *	$Id: thg71.c,v 1.19 2006/03/14 20:06:46 pa4tu Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -64,13 +64,12 @@ const struct kenwood_priv_caps  thg71_priv_caps  = {
 
 
 /* thg71 procs */
-int thg71_open(RIG *rig);
-int thg71_decode_event (RIG *rig);
-int thg71_set_freq (RIG *rig, vfo_t vfo, freq_t freq);
-int thg71_get_mode (RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
-int thg71_set_vfo (RIG *rig, vfo_t vfo);
-int thg71_get_vfo (RIG *rig, vfo_t *vfo);
-int thg71_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
+static int thg71_open(RIG *rig);
+static int thg71_decode_event (RIG *rig);
+static int thg71_get_mode (RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
+static int thg71_set_vfo (RIG *rig, vfo_t vfo);
+static int thg71_get_vfo (RIG *rig, vfo_t *vfo);
+static int thg71_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
 
 /*
  * th-g71 rig capabilities.
@@ -79,7 +78,7 @@ const struct rig_caps thg71_caps = {
 .rig_model =  RIG_MODEL_THG71,
 .model_name = "TH-G71",
 .mfg_name =  "Kenwood",
-.version =  "0.1",
+.version =  TH_VER,
 .copyright =  "LGPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_HANDHELD,
@@ -152,7 +151,7 @@ const struct rig_caps thg71_caps = {
 	RIG_FLT_END,
 	},
 
-.str_cal ={ 2, { {0, -30 }, {5,-13}}}, /* guessed from technical manual */
+.str_cal ={ 3, { { 0, -60 }, {1, -30 }, {5,-13}}}, /* guessed from technical manual */
 
 .priv =  (void *)&thg71_priv_caps,
 .rig_open =  thg71_open,
@@ -185,7 +184,8 @@ const struct rig_caps thg71_caps = {
 int thg71_decode_event (RIG *rig)
 {
     char asyncbuf[ACKBUF_LEN];
-    int retval, asyncbuf_len = ACKBUF_LEN-1;
+    int retval;
+    size_t asyncbuf_len = ACKBUF_LEN;
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
 
     retval = kenwood_transaction(rig, NULL, 0, asyncbuf, &asyncbuf_len);
@@ -199,7 +199,7 @@ int thg71_decode_event (RIG *rig)
         freq_t freq, offset;
         int step, shift, rev, tone, ctcss, tonefq, ctcssfq;
 
-        retval = sscanf(asyncbuf, "BUF 0,%"FREQFMT",%d,%d,%d,%d,%d,,%d,,%d,%"FREQFMT,
+        retval = sscanf(asyncbuf, "BUF 0,%"SCNfreq",%d,%d,%d,%d,%d,,%d,,%d,%"SCNfreq,
                                   &freq, &step, &shift, &rev, &tone,
                                   &ctcss, &tonefq, &ctcssfq, &offset);
         if (retval != 11) {
@@ -207,7 +207,7 @@ int thg71_decode_event (RIG *rig)
             return -RIG_ERJCTED;
         }
 
-        rig_debug(RIG_DEBUG_TRACE, "%s: Buffer (freq %"FREQFMT" Hz, mode %d)\n", __FUNCTION__, freq);
+        rig_debug(RIG_DEBUG_TRACE, "%s: Buffer (freq %"PRIfreq" Hz, mode %d)\n", __FUNCTION__, freq);
 
         /* Callback execution */
         if (rig->callbacks.vfo_event) {
@@ -292,7 +292,8 @@ int thg71_decode_event (RIG *rig)
 int thg71_get_mode (RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
     char ackbuf[ACKBUF_LEN];
-    int retval,ack_len=ACKBUF_LEN;
+    int retval;
+    size_t ack_len=ACKBUF_LEN;
     int step;
     freq_t freq;
 
@@ -311,7 +312,7 @@ int thg71_get_mode (RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         if (retval != RIG_OK)
         return retval;
 
-    sscanf(ackbuf,"FQ %"FREQFMT",%d",&freq,&step);
+    sscanf(ackbuf,"FQ %"SCNfreq",%d",&freq,&step);
 
     if(freq <MHz(136) )  {
 		*mode=RIG_MODE_AM;
@@ -328,7 +329,8 @@ int thg71_get_mode (RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 int thg71_set_vfo (RIG *rig, vfo_t vfo)
 {
     char vfobuf[16], ackbuf[ACKBUF_LEN];
-    int retval,ack_len=ACKBUF_LEN;
+    int retval;
+    size_t ack_len;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
 
@@ -345,6 +347,7 @@ int thg71_set_vfo (RIG *rig, vfo_t vfo)
             return -RIG_EVFO;
         }
 
+    ack_len = 0;
     retval = kenwood_transaction(rig, vfobuf, strlen(vfobuf), ackbuf, &ack_len);
         if (retval != RIG_OK)
         return retval;
@@ -356,7 +359,8 @@ int thg71_set_vfo (RIG *rig, vfo_t vfo)
 int thg71_get_vfo (RIG *rig, vfo_t *vfo)
 {
     char ackbuf[ACKBUF_LEN];
-    int retval,ack_len=ACKBUF_LEN;
+    int retval;
+    size_t ack_len=ACKBUF_LEN;
     int vch;
 
     retval = kenwood_transaction(rig, "VMC 0"EOM , 6, ackbuf, &ack_len);
@@ -383,11 +387,13 @@ int thg71_get_vfo (RIG *rig, vfo_t *vfo)
 int thg71_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 {
     char ackbuf[ACKBUF_LEN];
-    int retval,ack_len=ACKBUF_LEN;
+    int retval;
+    size_t ack_len;
 
      if(func != RIG_FUNC_TBURST)
 		return -RIG_EINVAL;
 
+    ack_len = 0;
     if(status==1) {
     retval = kenwood_transaction(rig, "TT"EOM, 3, ackbuf, &ack_len);
         if (retval != RIG_OK)
@@ -405,7 +411,8 @@ int thg71_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 int thg71_open(RIG *rig)
 {
     char ackbuf[ACKBUF_LEN],*strl,*stru;
-    int retval,i,ack_len=ACKBUF_LEN;
+    int retval,i;
+    size_t ack_len=ACKBUF_LEN;
     const freq_range_t frend=RIG_FRNG_END;
 
 	/* just to be sure it's a THG-71 */
@@ -453,6 +460,7 @@ int thg71_open(RIG *rig)
 	}
 	rig->state.rx_range_list[i]= frend;
 	rig->state.tx_range_list[i]= frend;
+	rig->state.vfo_list=RIG_VFO_A | RIG_VFO_MEM ;
 
     return RIG_OK;
 }
