@@ -1,8 +1,8 @@
 /*
  *  Hamlib Interface - extrq parameter interface
- *  Copyright (c) 2000,2001,2002 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: ext.c,v 1.2 2002/09/18 21:19:39 fillods Exp $
+ *	$Id: ext.c,v 1.6 2006/10/28 03:49:46 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -19,6 +19,20 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
+/**
+ * \addtogroup rig
+ * @{
+ */
+
+/**
+ * \file ext.c
+ * \brief Extension request parameter interface
+ *
+ * An open-ended set of extension parameters and levels are available for each rig,
+ * as provided in the rigcaps extparms and extlevels lists.  These provide a way
+ * to work with rig-specific functions that don't fit into the basic "virtual rig" of
+ * Hamlib.  See icom/ic746.c for an example.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -36,11 +50,13 @@
 
 
 
-/*
- * rig_ext_level_foreach
- * executes cfunc on all the elements stored in the extlevels table
- */
-int rig_ext_level_foreach(RIG *rig, int (*cfunc)(RIG *, const struct confparams *, rig_ptr_t), rig_ptr_t data)
+/**
+ * \param rig
+ * \param cfunc
+ * \param data
+  * \brief Executes cfunc on all the elements stored in the extlevels table
+*/
+int HAMLIB_API rig_ext_level_foreach(RIG *rig, int (*cfunc)(RIG *, const struct confparams *, rig_ptr_t), rig_ptr_t data)
 {
 	const struct confparams *cfp;
 
@@ -54,11 +70,13 @@ int rig_ext_level_foreach(RIG *rig, int (*cfunc)(RIG *, const struct confparams
 	return RIG_OK;
 }
 
-/*
- * rig_ext_parm_foreach
- * executes cfunc on all the elements stored in the extparms table
+/**
+ * \param rig
+ * \param cfunc The function to be called
+ * \param data The data
+ * \brief Executes cfunc on all the elements stored in the extparms table
  */
-int rig_ext_parm_foreach(RIG *rig, int (*cfunc)(RIG *, const struct confparams *, rig_ptr_t), rig_ptr_t data)
+int HAMLIB_API rig_ext_parm_foreach(RIG *rig, int (*cfunc)(RIG *, const struct confparams *, rig_ptr_t), rig_ptr_t data)
 {
 	const struct confparams *cfp;
 
@@ -72,17 +90,18 @@ int rig_ext_parm_foreach(RIG *rig, int (*cfunc)(RIG *, const struct confparams *
 	return RIG_OK;
 }
 
-
-
-/*
- * lookup ext token by its name, return pointer to confparams struct.
+/**
+ * \param rig
+ * \param name
+ * \brief lookup ext token by its name, return pointer to confparams struct.
  *
- * lookup extlevels table first, then fall back to extparms.
+ * Lookup extlevels table first, then fall back to extparms.
  *
  * Returns NULL if nothing found
+ *
  * TODO: should use Lex to speed it up, strcmp hurts!
  */
-const struct confparams *rig_ext_lookup(RIG *rig, const char *name)
+const struct confparams * HAMLIB_API rig_ext_lookup(RIG *rig, const char *name)
 {
 	const struct confparams *cfp;
 
@@ -98,10 +117,37 @@ const struct confparams *rig_ext_lookup(RIG *rig, const char *name)
 	return NULL;
 }
 
-/*
- * Simple lookup returning token id assicated with name
+/**
+ * \param rig
+ * \param token
+ * \brief lookup ext token, return pointer to confparams struct.
+ *
+ * lookup extlevels table first, then fall back to extparms.
+ *
+ * Returns NULL if nothing found
  */
-token_t rig_ext_token_lookup(RIG *rig, const char *name)
+const struct confparams * HAMLIB_API rig_ext_lookup_tok(RIG *rig, token_t token)
+{
+	const struct confparams *cfp;
+
+	if (!rig || !rig->caps)
+		return NULL;
+
+	for (cfp = rig->caps->extlevels; cfp && cfp->token; cfp++)
+		if (cfp->token == token)
+			return cfp;
+	for (cfp = rig->caps->extparms; cfp && cfp->token; cfp++)
+		if (cfp->token == token)
+			return cfp;
+	return NULL;
+}
+
+/**
+ * \param rig
+ * \param name
+ * \brief Simple lookup returning token id assicated with name
+ */
+token_t HAMLIB_API rig_ext_token_lookup(RIG *rig, const char *name)
 {
 	const struct confparams *cfp;
 
@@ -112,4 +158,4 @@ token_t rig_ext_token_lookup(RIG *rig, const char *name)
 	return cfp->token;
 }
 
-
+/** @} */
