@@ -30,7 +30,7 @@ int main (int argc, char *argv[])
 	 */
 
 	if (argc < 2) {
-		port_t myport;
+		hamlib_port_t myport;
 		/* may be overriden by backend probe */
 		myport.type.rig = RIG_PORT_SERIAL;
 		myport.parm.serial.rate = 9600;
