@@ -1,11 +1,11 @@
 /*
- * rotctl.c - (C) Stephane Fillod 2000-2003
+ * rotctl.c - (C) Stephane Fillod 2000-2004
  *
  * This program test/control a rotator using Hamlib.
  * It takes commands in interactive mode as well as 
  * from command line options.
  *
- * $Id: rotctl.c,v 1.7 2003/04/07 20:54:18 fillods Exp $  
+ *	$Id: rotctl.c,v 1.9 2006/10/07 19:12:35 csete Exp $  
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -79,15 +79,6 @@ void list_models();
 static int print_conf_list(const struct confparams *cfp, rig_ptr_t data);
 int set_conf(ROT *my_rot, char *conf_parms);
 
-rmode_t parse_mode(const char *s);
-vfo_t parse_vfo(const char *s);
-setting_t parse_func(const char *s);
-setting_t parse_level(const char *s);
-setting_t parse_parm(const char *s);
-vfo_op_t parse_vfo_op(const char *s);
-scan_t parse_scan(const char *s);
-rptr_shift_t parse_rptr_shift(const char *s);
-
 #define declare_proto_rot(f) static int (f)(ROT *rot, int interactive, \
 			const struct test_table *cmd, const char *arg1, \
 			const char *arg2, const char *arg3)
@@ -314,7 +305,7 @@ int main (int argc, char *argv[])
 						while(c_len-- && (isalnum(*pcmd) || *pcmd == '_' ))
 							scanf("%c", ++pcmd);
 						*pcmd = '\0';
-						cmd = parse_arg(cmd_name);
+						cmd = parse_arg((char *) cmd_name);
 						break;
 					}
 
@@ -487,6 +478,8 @@ static int print_conf_list(const struct confparams *cfp, rig_ptr_t data)
 				printf(", %s", cfp->u.c.combostr[i]);
 		printf("\n");
 		break;
+        default:
+          break;
 	}
 
 	return 1;  /* !=0, we want them all ! */
