@@ -1,10 +1,10 @@
 /*
- * ft1000.c - (C) Stephane Fillod 2002-2003 (fillods@users.sourceforge.net)
+ * ft1000.c - (C) Stephane Fillod 2002-2005 (fillods@users.sourceforge.net)
  *
  * This shared library provides an API for communicating
  * via serial interface to an FT-1000MP using the "CAT" interface
  *
- *	$Id: ft1000mp.c,v 1.3 2003/11/16 17:14:44 fillods Exp $
+ *	$Id: ft1000mp.c,v 1.7 2006/10/07 15:51:38 csete Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -48,6 +48,11 @@
 #include "yaesu.h"
 #include "ft1000mp.h"
 
+/*
+ * Differences between FT1000MP:
+ * The FT1000MP MARK-V Field appears to be identical to FT1000MP,
+ * whereas the FT1000MP MARK-V is a FT1000MP with 200W. TBC.
+ */
 
 /* Private helper function prototypes */
 
@@ -140,7 +145,7 @@ static const yaesu_cmd_set_t ncmd[] = {
 /**
  * 33 CTCSS sub-audible tones
  */
-const tone_t ft1000mp_ctcss_list[] = {
+static const tone_t ft1000mp_ctcss_list[] = {
 	      670,        719,        770,        825,        885,      
 	948,       1000, 1035, 1072, 1109, 1148, 1188,       1230, 1273,
 	1318, 1365, 1413, 1462, 1514, 1567, 1598, 1622,       1679,
@@ -200,6 +205,131 @@ struct ft1000mp_priv_data {
 
 const struct rig_caps ft1000mp_caps = {
   .rig_model =          RIG_MODEL_FT1000MP,
+  .model_name =         "FT-1000MP",
+  .mfg_name =           "Yaesu",
+  .version =            "0.1",
+  .copyright =          "LGPL",
+  .status =             RIG_STATUS_ALPHA,
+  .rig_type =           RIG_TYPE_TRANSCEIVER,
+  .ptt_type =           RIG_PTT_RIG,
+  .dcd_type =           RIG_DCD_RIG,
+  .port_type =          RIG_PORT_SERIAL,
+  .serial_rate_min =    4800,
+  .serial_rate_max =    4800,
+  .serial_data_bits =   8,
+  .serial_stop_bits =   2,
+  .serial_parity =      RIG_PARITY_NONE,
+  .serial_handshake =   RIG_HANDSHAKE_NONE,
+  .write_delay =        FT1000MP_WRITE_DELAY,
+  .post_write_delay =   FT1000MP_POST_WRITE_DELAY,
+  .timeout =            2000,
+  .retry =              0,
+  .has_get_func =       FT1000MP_FUNC_ALL,
+  .has_set_func =       FT1000MP_FUNC_ALL,
+  .has_get_level =      FT1000MP_LEVEL_GET,
+  .has_set_level =      RIG_LEVEL_NONE,	/* as strange as it could be */
+  .has_get_parm =       RIG_PARM_NONE,
+  .has_set_parm =       RIG_PARM_NONE,
+  .ctcss_list =         ft1000mp_ctcss_list,
+  .dcs_list =           NULL,
+  .vfo_ops =		FT1000MP_VFO_OPS,
+  .preamp =             { RIG_DBLST_END, },
+  .attenuator =         { RIG_DBLST_END, },
+  .max_rit =            Hz(9999),
+  .max_xit =            Hz(9999),
+  .max_ifshift =        kHz(1.12),
+  .targetable_vfo =     RIG_TARGETABLE_FREQ,
+  .transceive =         RIG_TRN_OFF,
+  .bank_qty =           0,
+  .chan_desc_sz =       0,
+  .chan_list =          { 
+				{   1,  99, RIG_MTYPE_MEM, FT1000MP_MEM_CAP },
+				{ 100, 108, RIG_MTYPE_EDGE },	/* P1 .. P9 */
+				{ 109, 113, RIG_MTYPE_MEMOPAD }, /* Q1 .. Q5 */
+				RIG_CHAN_END,
+			},
+  .rx_range_list1 =     { 
+    {kHz(100), MHz(30), FT1000MP_ALL_RX_MODES, -1, -1, FT1000MP_VFOS, FT1000MP_ANTS },   /* General coverage + ham */
+    RIG_FRNG_END,
+  }, /* Region 1 rx ranges */
+
+  .tx_range_list1 =     {
+	FRQ_RNG_HF(1,FT1000MP_OTHER_TX_MODES, W(5),W(100),FT1000MP_VFOS,FT1000MP_ANTS),
+	FRQ_RNG_HF(1,FT1000MP_AM_TX_MODES, W(2),W(25),FT1000MP_VFOS,FT1000MP_ANTS),  /* AM class */
+	RIG_FRNG_END,
+  },    /* region 1 TX ranges */
+
+  .rx_range_list2 =     {
+    {kHz(100), MHz(30), FT1000MP_ALL_RX_MODES, -1, -1, FT1000MP_VFOS, FT1000MP_ANTS },   /* General coverage + ham */
+    RIG_FRNG_END,
+  }, /* Region 2 rx ranges */
+
+  .tx_range_list2 =     {
+	FRQ_RNG_HF(1,FT1000MP_OTHER_TX_MODES, W(5),W(100),FT1000MP_VFOS,FT1000MP_ANTS),
+	FRQ_RNG_HF(1,FT1000MP_AM_TX_MODES, W(2),W(25),FT1000MP_VFOS,FT1000MP_ANTS),  /* AM class */
+	RIG_FRNG_END,
+  },    /* region 2 TX ranges */
+
+  .tuning_steps =       {
+    {RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_RTTY, Hz(10)},    /* Normal */
+    {RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_RTTY, Hz(100)},   /* Fast */
+
+    {RIG_MODE_AM,     Hz(100)},   /* Normal */
+    {RIG_MODE_AM,     kHz(1)},    /* Fast */
+
+    {RIG_MODE_FM,     Hz(100)},   /* Normal */
+    {RIG_MODE_FM,     kHz(1)},    /* Fast */
+
+    RIG_TS_END,
+
+    /*
+     * The FT-1000MP has a Fine tuning step which increments in 1 Hz steps
+     * for SSB_CW_RX_MODES, and 10 Hz steps for AM_RX_MODES and
+     * FM_RX_MODES.  It doesn't appear that anything finer than 10 Hz
+     * is available through the CAT interface, however. -N0NB
+     *
+     */
+  },
+
+    /* mode/filter list, .remember =  order matters! */
+  .filters =            {
+    {RIG_MODE_SSB|RIG_MODE_CW|RIG_MODE_RTTY|RIG_MODE_AM,  kHz(2.4)},
+    {RIG_MODE_SSB|RIG_MODE_CW|RIG_MODE_RTTY,  kHz(2.0)},
+    {RIG_MODE_CW|RIG_MODE_RTTY,   Hz(500)},
+    {RIG_MODE_CW|RIG_MODE_RTTY,   Hz(250)},
+    {RIG_MODE_AM,   kHz(5)},	/* wide */
+    {RIG_MODE_FM,   kHz(8)},   /* FM */
+
+    RIG_FLT_END,
+  },
+  .str_cal = FT1000MP_STR_CAL,
+
+  .priv =               NULL,           /* private data */
+
+  .rig_init =           ft1000mp_init,
+  .rig_cleanup =        ft1000mp_cleanup,
+  .rig_open =           ft1000mp_open,     /* port opened */
+
+  .set_freq =           ft1000mp_set_freq, /* set freq */
+  .get_freq =           ft1000mp_get_freq, /* get freq */
+  .set_mode =           ft1000mp_set_mode, /* set mode */
+  .get_mode =           ft1000mp_get_mode, /* get mode */
+  .set_vfo =            ft1000mp_set_vfo,  /* set vfo */
+  .get_vfo =            ft1000mp_get_vfo,  /* get vfo */
+
+  .get_rit =            ft1000mp_get_rit,
+  .set_rit =            ft1000mp_set_rit,
+  .get_xit =            ft1000mp_get_xit,
+  .set_xit =            ft1000mp_set_xit,
+
+  .get_level =          ft1000mp_get_level,
+  .set_ptt =            ft1000mp_set_ptt,
+
+  /* TODO: the remaining ... */
+};
+
+const struct rig_caps ft1000mpmkv_caps = {
+  .rig_model =          RIG_MODEL_FT1000MPMKV,
   .model_name =         "MARK-V FT-1000MP",
   .mfg_name =           "Yaesu",
   .version =            "0.0.5",
@@ -248,6 +378,131 @@ const struct rig_caps ft1000mp_caps = {
     RIG_FRNG_END,
   }, /* Region 1 rx ranges */
 
+  .tx_range_list1 =     {
+	FRQ_RNG_HF(1,FT1000MP_OTHER_TX_MODES, W(5),W(200),FT1000MP_VFOS,FT1000MP_ANTS),
+	FRQ_RNG_HF(1,FT1000MP_AM_TX_MODES, W(2),W(50),FT1000MP_VFOS,FT1000MP_ANTS),  /* AM class */
+	RIG_FRNG_END,
+  },    /* region 1 TX ranges */
+
+  .rx_range_list2 =     {
+    {kHz(100), MHz(30), FT1000MP_ALL_RX_MODES, -1, -1, FT1000MP_VFOS, FT1000MP_ANTS },   /* General coverage + ham */
+    RIG_FRNG_END,
+  }, /* Region 2 rx ranges */
+
+  .tx_range_list2 =     {
+	FRQ_RNG_HF(1,FT1000MP_OTHER_TX_MODES, W(5),W(200),FT1000MP_VFOS,FT1000MP_ANTS),
+	FRQ_RNG_HF(1,FT1000MP_AM_TX_MODES, W(2),W(50),FT1000MP_VFOS,FT1000MP_ANTS),  /* AM class */
+	RIG_FRNG_END,
+  },    /* region 2 TX ranges */
+
+  .tuning_steps =       {
+    {RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_RTTY, Hz(10)},    /* Normal */
+    {RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_RTTY, Hz(100)},   /* Fast */
+
+    {RIG_MODE_AM,     Hz(100)},   /* Normal */
+    {RIG_MODE_AM,     kHz(1)},    /* Fast */
+
+    {RIG_MODE_FM,     Hz(100)},   /* Normal */
+    {RIG_MODE_FM,     kHz(1)},    /* Fast */
+
+    RIG_TS_END,
+
+    /*
+     * The FT-1000MP has a Fine tuning step which increments in 1 Hz steps
+     * for SSB_CW_RX_MODES, and 10 Hz steps for AM_RX_MODES and
+     * FM_RX_MODES.  It doesn't appear that anything finer than 10 Hz
+     * is available through the CAT interface, however. -N0NB
+     *
+     */
+  },
+
+    /* mode/filter list, .remember =  order matters! */
+  .filters =            {
+    {RIG_MODE_SSB|RIG_MODE_CW|RIG_MODE_RTTY|RIG_MODE_AM,  kHz(2.4)},
+    {RIG_MODE_SSB|RIG_MODE_CW|RIG_MODE_RTTY,  kHz(2.0)},
+    {RIG_MODE_CW|RIG_MODE_RTTY,   Hz(500)},
+    {RIG_MODE_CW|RIG_MODE_RTTY,   Hz(250)},
+    {RIG_MODE_AM,   kHz(5)},	/* wide */
+    {RIG_MODE_FM,   kHz(8)},   /* FM */
+
+    RIG_FLT_END,
+  },
+  .str_cal = FT1000MP_STR_CAL,
+
+  .priv =               NULL,           /* private data */
+
+  .rig_init =           ft1000mp_init,
+  .rig_cleanup =        ft1000mp_cleanup,
+  .rig_open =           ft1000mp_open,     /* port opened */
+
+  .set_freq =           ft1000mp_set_freq, /* set freq */
+  .get_freq =           ft1000mp_get_freq, /* get freq */
+  .set_mode =           ft1000mp_set_mode, /* set mode */
+  .get_mode =           ft1000mp_get_mode, /* get mode */
+  .set_vfo =            ft1000mp_set_vfo,  /* set vfo */
+  .get_vfo =            ft1000mp_get_vfo,  /* get vfo */
+
+  .get_rit =            ft1000mp_get_rit,
+  .set_rit =            ft1000mp_set_rit,
+  .get_xit =            ft1000mp_get_xit,
+  .set_xit =            ft1000mp_set_xit,
+
+  .get_level =          ft1000mp_get_level,
+  .set_ptt =            ft1000mp_set_ptt,
+
+  /* TODO: the remaining ... */
+};
+
+const struct rig_caps ft1000mpmkvfld_caps = {
+  .rig_model =          RIG_MODEL_FT1000MPMKVFLD,
+  .model_name =         "MARK-V Field FT-1000MP",
+  .mfg_name =           "Yaesu",
+  .version =            "0.0.5",
+  .copyright =          "LGPL",
+  .status =             RIG_STATUS_ALPHA,
+  .rig_type =           RIG_TYPE_TRANSCEIVER,
+  .ptt_type =           RIG_PTT_RIG,
+  .dcd_type =           RIG_DCD_RIG,
+  .port_type =          RIG_PORT_SERIAL,
+  .serial_rate_min =    4800,
+  .serial_rate_max =    4800,
+  .serial_data_bits =   8,
+  .serial_stop_bits =   2,
+  .serial_parity =      RIG_PARITY_NONE,
+  .serial_handshake =   RIG_HANDSHAKE_NONE,
+  .write_delay =        FT1000MP_WRITE_DELAY,
+  .post_write_delay =   FT1000MP_POST_WRITE_DELAY,
+  .timeout =            2000,
+  .retry =              0,
+  .has_get_func =       FT1000MP_FUNC_ALL,
+  .has_set_func =       FT1000MP_FUNC_ALL,
+  .has_get_level =      FT1000MP_LEVEL_GET,
+  .has_set_level =      RIG_LEVEL_NONE,	/* as strange as it could be */
+  .has_get_parm =       RIG_PARM_NONE,
+  .has_set_parm =       RIG_PARM_NONE,
+  .ctcss_list =         ft1000mp_ctcss_list,
+  .dcs_list =           NULL,
+  .vfo_ops =		FT1000MP_VFO_OPS,
+  .preamp =             { RIG_DBLST_END, },
+  .attenuator =         { RIG_DBLST_END, },
+  .max_rit =            Hz(9999),
+  .max_xit =            Hz(9999),
+  .max_ifshift =        kHz(1.12),
+  .targetable_vfo =     RIG_TARGETABLE_FREQ,
+  .transceive =         RIG_TRN_OFF,
+  .bank_qty =           0,
+  .chan_desc_sz =       0,
+  .chan_list =          { 
+				{   1,  99, RIG_MTYPE_MEM, FT1000MP_MEM_CAP },
+				{ 100, 108, RIG_MTYPE_EDGE },	/* P1 .. P9 */
+				{ 109, 113, RIG_MTYPE_MEMOPAD }, /* Q1 .. Q5 */
+				RIG_CHAN_END,
+			},
+  .rx_range_list1 =     { 
+    {kHz(100), MHz(30), FT1000MP_ALL_RX_MODES, -1, -1, FT1000MP_VFOS, FT1000MP_ANTS },   /* General coverage + ham */
+    RIG_FRNG_END,
+  }, /* Region 1 rx ranges */
+
   .tx_range_list1 =     {
 	FRQ_RNG_HF(1,FT1000MP_OTHER_TX_MODES, W(5),W(100),FT1000MP_VFOS,FT1000MP_ANTS),
 	FRQ_RNG_HF(1,FT1000MP_AM_TX_MODES, W(2),W(25),FT1000MP_VFOS,FT1000MP_ANTS),  /* AM class */
@@ -403,7 +658,7 @@ int ft1000mp_open(RIG *rig) {
 
   /* send PACING cmd to rig  */
   cmd = p->p_cmd;
-  write_block(&rig_s->rigport, cmd, YAESU_CMD_LENGTH);
+  write_block(&rig_s->rigport, (char *) cmd, YAESU_CMD_LENGTH);
 
    /* TODO */
 
@@ -425,7 +680,7 @@ int ft1000mp_set_freq(RIG *rig, vfo_t vfo, freq_t freq) {
 
   rig_s = &rig->state;
 
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: requested freq = %lli Hz \n", freq);
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: requested freq = %"PRIfreq" Hz \n", freq);
 
   if (vfo == RIG_VFO_CURR)
 	  vfo = p->current_vfo;
@@ -452,11 +707,11 @@ int ft1000mp_set_freq(RIG *rig, vfo_t vfo, freq_t freq) {
   to_bcd(p->p_cmd,freq/10,8);   /* store bcd format in in p_cmd */
                                 /* TODO -- fix 10Hz resolution -- FS */
 
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: requested freq after conversion = %lli Hz\n",
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: requested freq after conversion = %"PRIll" Hz\n",
             from_bcd(p->p_cmd,8)* 10 );
 
   cmd = p->p_cmd;               /* get native sequence */
-  write_block(&rig_s->rigport, cmd, YAESU_CMD_LENGTH);
+  write_block(&rig_s->rigport, (char *) cmd, YAESU_CMD_LENGTH);
 
   return RIG_OK;
 }
@@ -503,7 +758,7 @@ int ft1000mp_get_freq(RIG *rig, vfo_t vfo, freq_t *freq) {
   /* big endian integer, kinda */
   f = ((((((p[0]<<8) + p[1])<<8) + p[2])<<8) + p[3])*10/16;
 
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: freq = %lli Hz for VFO [%x]\n", f, vfo);
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: freq = %"PRIfreq" Hz for VFO [%x]\n", f, vfo);
 
   *freq = f;                    /* return diplayed frequency */
 
@@ -642,7 +897,7 @@ int ft1000mp_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width) {
     break; 
   }
  
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: mode = %s\n", strrmode(*mode));
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: mode = %s\n", rig_strrmode(*mode));
 
   /* TODO: set real IF filter selection */
   *width = RIG_PASSBAND_NORMAL;
@@ -662,7 +917,7 @@ int ft1000mp_set_vfo(RIG *rig, vfo_t vfo) {
   struct ft1000mp_priv_data *p;
   unsigned char cmd_index = 0;      /* index of sequence to send */
 
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: ft1000mp_set_vfo called %s\n", strvfo(vfo));
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: ft1000mp_set_vfo called %s\n", rig_strvfo(vfo));
 
   
   p = (struct ft1000mp_priv_data*)rig->state.priv;
@@ -767,7 +1022,7 @@ int ft1000mp_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit) {
   priv->p_cmd[2] = rit >= 0 ? 0x00 : 0xff;
 
   cmd = priv->p_cmd;               /* get native sequence */
-  write_block(&rs->rigport, cmd, YAESU_CMD_LENGTH);
+  write_block(&rs->rigport, (char *) cmd, YAESU_CMD_LENGTH);
 
   return RIG_OK;
 }
@@ -820,7 +1075,7 @@ int ft1000mp_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit) {
 
   f = f*10/16;
 
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: freq = %lli Hz for VFO [%x]\n", f, vfo);
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: freq = %li Hz for VFO [%x]\n", f, vfo);
 
   *rit = f;		/* return diplayed frequency */
 
@@ -852,7 +1107,7 @@ int ft1000mp_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit) {
   priv->p_cmd[2] = xit >= 0 ? 0x00 : 0xff;
 
   cmd = priv->p_cmd;               /* get native sequence */
-  write_block(&rs->rigport, cmd, YAESU_CMD_LENGTH);
+  write_block(&rs->rigport, (char *) cmd, YAESU_CMD_LENGTH);
 
   return RIG_OK;
 }
@@ -905,7 +1160,7 @@ int ft1000mp_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit) {
 
   f = f*10/16;
 
-  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: freq = %lli Hz for VFO [%x]\n", f, vfo);
+  rig_debug(RIG_DEBUG_TRACE,"ft1000mp: freq = %li Hz for VFO [%x]\n", f, vfo);
 
   *xit = f;		/* return diplayed frequency */
 
@@ -963,9 +1218,9 @@ int ft1000mp_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 	memset(&priv->p_cmd, m, YAESU_CMD_LENGTH-1);
 	priv->p_cmd[4] = 0xf7;
 
-	write_block(&rs->rigport, priv->p_cmd, YAESU_CMD_LENGTH);
+	write_block(&rs->rigport, (char *) priv->p_cmd, YAESU_CMD_LENGTH);
 
-	retval = read_block(&rs->rigport, lvl_data, YAESU_CMD_LENGTH);
+	retval = read_block(&rs->rigport, (char *) lvl_data, YAESU_CMD_LENGTH);
 	if (retval != YAESU_CMD_LENGTH) {
 		rig_debug(RIG_DEBUG_ERR,"ft1000mp_get_level: ack NG %d", retval);
 		return retval;
@@ -1027,7 +1282,7 @@ static int ft1000mp_get_update_data(RIG *rig, unsigned char ci, unsigned char rl
   /* send UPDATE comand to fetch data*/
   ft1000mp_send_priv_cmd(rig, ci);
 
-  n = read_block(&rig_s->rigport, p->update_data, rl);
+  n = read_block(&rig_s->rigport, (char *) p->update_data, rl);
 
   return n;
 
@@ -1062,7 +1317,7 @@ static int ft1000mp_send_priv_cmd(RIG *rig, unsigned char ci) {
   }
 
   cmd = (unsigned char *) p->pcs[cmd_index].nseq; /* get native sequence */
-  write_block(&rig_s->rigport, cmd, YAESU_CMD_LENGTH);
+  write_block(&rig_s->rigport, (char *) cmd, YAESU_CMD_LENGTH);
   
   return RIG_OK;
 
